@@ -1,5 +1,6 @@
 import json
 import os
+import shutil
 
 import click
 import msal
@@ -9,6 +10,8 @@ from time import sleep
 from .config import (
     get_config_path,
     get_api_config,
+    get_legacy_config_path,
+    get_legacy_token_path,
     get_token_path,
     ARCHIMEDES_CONF_DIR,
 )
@@ -37,6 +40,7 @@ def get_accepted_env():
             sleep(3)
     raise Exception("Unable to get config from arclconfig.")
 
+
 class ArchimedesAuth:
     def __init__(self, env):
         self.env = env
@@ -136,6 +140,10 @@ class ArchimedesAuth:
             open(self.saved_config_path, "w").write(config_json)
             click.echo(f"Login successful into env: {self.env}")
 
+            # copy jsona and msal to default files for backward compatibility
+            shutil.copy(self.saved_config_path, get_legacy_config_path())
+            shutil.copy(self.token_path, get_legacy_token_path())
+
     @staticmethod
     def show():
         all_env_details = {}
